@@ -90,12 +90,6 @@ class ApiBase(object):
 
       res = self.__make_request(req_args)
 
-      res_data = None
-      try:
-        res_data = res.json()
-      except ValueError:
-        res_data = res.text
-    
       if res.status_code == 503:
         raise UnavailableException()
       
@@ -109,6 +103,13 @@ class ApiBase(object):
         raise UnauthorizedException(res.content)
       
       elif res.status_code == 400:
+        res_data = None
+
+        try:
+          res_data = res.json()
+        except ValueError:
+          res_data = res.text
+
         raise BadRequestException(
           message='Bad request from API',
           response_body=res_data,
@@ -119,9 +120,9 @@ class ApiBase(object):
         raise Exception(res.content)
         
       logging.info(f'{str(http_method).upper()} response:')
-      logging.info(res_data)
+      logging.info(jsonpickle.encode(res))
       
-      return res_data
+      return res
     
     except UnavailableException as e:
       raise e
